TransactionPayloadDecoder class
Decodes base64-encoded transaction payloads from PushSaleV1 CloudEvents into ReceivedTransaction objects.
The payload format matches the transactionPayload field sent by the
Cloud POS API when staging a transaction via Terminal Manager's PushSale.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
decode(
String base64Payload) → ReceivedTransaction - Decodes a base64-encoded transaction payload string.
-
decodeFromJson(
Map< String, dynamic> json) → ReceivedTransaction - Decodes a raw JSON map payload (when the event data is already decoded).
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited